package frc.robot.subsystems;

import edu.wpi.first.networktables.BooleanSubscriber;
import edu.wpi.first.networktables.DoubleSubscriber;
import edu.wpi.first.networktables.NetworkTable;
import edu.wpi.first.networktables.NetworkTableInstance;

public class Vision{

    private DoubleSubscriber blackRobotRelativePose;
    private DoubleSubscriber blackClosestTag;
    private BooleanSubscriber blackTagDetected;

    private DoubleSubscriber blackFramerate;

    private DoubleSubscriber orangeRobotRelativePose;
    private DoubleSubscriber orangeClosestTag;
    private BooleanSubscriber orangeTagDetected;

    private DoubleSubscriber orangeFramerate;

    public Vision(){
        NetworkTableInstance inst = NetworkTableInstance.getDefault();

        NetworkTable blackVisionTable = inst.getTable("black_Fiducial");
        NetworkTable orangeVisionTable = inst.getTable("orange_Fiducial");

        blackRobotRelativePose = blackVisionTable.getDoubleTopic("blackRelativePose").subscribe(0.0);
        blackClosestTag = blackVisionTable.getDoubleTopic("blackClosestTag").subscribe(0.0);
        blackTagDetected = blackVisionTable.getBooleanTopic("blackTagDetected").subscribe(false);

        blackFramerate = blackVisionTable.getDoubleTopic("blackFPS").subscribe(0.0);

        orangeRobotRelativePose = orangeVisionTable.getDoubleTopic("orangeRelativePose").subscribe(0.0);
        orangeClosestTag = orangeVisionTable.getDoubleTopic("orangeClosestTag").subscribe(0.0);
        orangeTagDetected = orangeVisionTable.getBooleanTopic("orangeTagDetected").subscribe(false);

        orangeFramerate = orangeVisionTable.getDoubleTopic("orangeFPS").subscribe(0.0);
    }

    public double getBlackGlobalPose(){
        return blackRobotRelativePose.get();
    }

    public double getBlackClosestTag(){
        return blackClosestTag.get();
    }

    public double getBlackTimeStamp(){
        return blackRobotRelativePose.getLastChange();
    }

    public boolean getBlackTagDetected(){
        return blackTagDetected.get();
    }

    public double getBlackFPS(){
        return blackFramerate.get();
    }
    
    public double getOrangeGlobalPose(){
        return orangeRobotRelativePose.get();
    }

    public double getOrangeClosestTag(){
        return orangeClosestTag.get();
    }

    public double getOrangeTimeStamp(){
        return orangeRobotRelativePose.getLastChange();
    }

    public boolean getOrangeTagDetected(){
        return orangeTagDetected.get();
    }

    public double getOrangeFPS(){
        return orangeFramerate.get();
    }
    
}
